# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][clog], and this project adheres to [Semantic Versioning][semver].

## [Unreleased]

## [0.1.1] - 2021-08-13
### Added
- Allow getting the value from a single setting

## [0.1.0] - 2021-07-01
### Added
- Allow including python files for settings

[unreleased]: https://github.com/spapanik/dj_settings/compare/v0.1.1...main
[0.1.1]: https://github.com/spapanik/dj_settings/compare/v0.1.0...v0.1.1

[clog]: https://keepachangelog.com/en/1.0.0/
[semver]: https://semver.org/spec/v2.0.0.html
